# chatgpt-cli-python
Simple CLI tool for asking ChatGPT questions from the terminal

### Getting started
Download by running `pip install quaero`
Run `quaero init` and follow instructions to add your OpenAI key

### Usage
Once your API key is set up, simply run `quaero` and ask your question
Subsequent questions will be part of the same conversation
Exit with control C
The conversation ID printed on exit can be used to resume the conversation by running the script again with `quaero -c <ID>`

### Links
https://github.com/yeo-yeo/chatgpt-cli-python
https://pypi.org/project/quaero/